import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { CreateGroupOptions, DeleteGroupResponse, GetGroupBySlugOptions, GetGroupBySlugResponse, GetGroupOptions, Group, GroupCoverChangedEnvelope, GroupCreatedEnvelope, GroupDeletedEnvelope, GroupDescriptionChangedEnvelope, GroupUpdatedEnvelope, GroupsQueryBuilder, ListGroupsOptions, ListGroupsResponse, QueryGroupsOptions, UpdateGroup, UpdateGroupOptions } from './social-groups-v2-group-groups.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createGroup(httpClient: HttpClient): CreateGroupSignature;
interface CreateGroupSignature {
    /**
     * Creates a group.
     *
     * When a group is created, the newly created group is added to the [Groups List](https://support.wix.com/en/article/wix-groups-about-your-groups-pages#groups-group-list) page
     * of a site.
     *
     * Specify a `creatorId` to set the group's creator. The group's creator will automatically become a group admin, see Terminology ([REST](https://dev.wix.com/docs/rest/crm/community/groups/terminology) | [SDK](https://dev.wix.com/docs/sdk/backend-modules/groups/terminology)).
     *
     * Wix users determine who can create a group.
     * This setting can be found in [a site's Dashboard](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fwix-groups/settings?) under **Groups > General Settings > Group Creation**.
     * If set to **members with approval**, site members can create a group with the Create Group method, and the group becomes a `createRequest` with a status of `PENDING`.
     * A Wix user either approves or rejects the request to create a group.
     * If set to **all site members**, site members can create a group with the Create Group method and no approval is required.
     * If set to **only admins**, only Wix users can create a group with the Create Group method.
     * Default is set to **members with approval**.
     * @param - Group to create.
     * @param - Optional fields for group creation.
     * @returns Created group.
     */
    (group: Group, options?: CreateGroupOptions | undefined): Promise<Group>;
}
export declare function updateGroup(httpClient: HttpClient): UpdateGroupSignature;
interface UpdateGroupSignature {
    /**
     * Updates a group.
     *
     * When a public or private group's name is updated, the slug is updated to reflect the new group name.
     * Only group admins can update their group.
     *
     * > **Notes:**
     * > + When `group.privacyStatus` is updated from `PRIVATE` to `PUBLIC`, all pending group join requests are automatically approved.
     * > + When `group.privacyStatus` is updated from `PRIVATE` to `SECRET`, all pending group join requests are automatically rejected.
     * @param - Group ID.
     * @returns Updated group.
     */
    (_id: string, group: UpdateGroup, options?: UpdateGroupOptions | undefined): Promise<Group>;
}
export declare function deleteGroup(httpClient: HttpClient): DeleteGroupSignature;
interface DeleteGroupSignature {
    /**
     * Hides a group from the [Groups List](https://support.wix.com/en/article/wix-groups-about-your-groups-pages#groups-group-list) or cancels a group request.
     *
     * >**Notes:**
     * > + Only group admins can delete their group.
     * > + The group will no longer be visible in the live site or the dashboard.
     * > + It is not possible to restore a deleted group with the Update Group method.
     * > + It is still possible to retrieve the group with the Get Group, List Groups, and Query Groups methods.
     * @param - ID of the group to delete.
     */
    (groupId: string): Promise<DeleteGroupResponse>;
}
export declare function getGroup(httpClient: HttpClient): GetGroupSignature;
interface GetGroupSignature {
    /**
     * Retrieves a group.
     *
     * For groups with `group.privacyStatus` set to `SECRET`, only group admins and group members can see the group and its content.
     * @param - ID of the group to retrieve.
     * @returns Retrieved group.
     */
    (groupId: string, options?: GetGroupOptions | undefined): Promise<Group>;
}
export declare function getGroupBySlug(httpClient: HttpClient): GetGroupBySlugSignature;
interface GetGroupBySlugSignature {
    /**
     * Retrieves a group by slug.
     *
     * The slug is the end of a group's URL that refers to a specific group.
     * For example, if a group's URL is `https:/example.com/groups/{my-fitness-group}`, the slug is `my-fitness-group`.
     * Slugs are case-sensitive. It is generally based on the group name, but for secret groups it is an autogenerated string of characters,
     * for example, `https:/example.com/groups/{5D3yTX}`.
     *
     * For groups with `group.privacyStatus` set to `SECRET`, only group admins and group members can see the group and its content.
     * @param - Unique part of the group's URL. For example, if a group's URL is `https:/example.com/groups/{my-fitness-group}`, the slug is `my-fitness-group`. Case-sensitive.
     */
    (slug: string, options?: GetGroupBySlugOptions | undefined): Promise<GetGroupBySlugResponse>;
}
export declare function listGroups(httpClient: HttpClient): ListGroupsSignature;
interface ListGroupsSignature {
    /**
     * Retrieves up to 100 groups.
     *
     *
     * Default sorts by `_createdDate` in descending order. For `SECRET` groups, only group admins and group members can see a list of groups and their content.
     *
     * > **Note:** This function's parameters are positional, and must be specified in the sequence shown in the syntax below. When specifying a parameter, use `null` as a placeholder for any unspecified parameters. For example, to specify limit only, call `listGroups(paging, null)`.
     * @param - Limit and offset options.
     */
    (options?: ListGroupsOptions | undefined): Promise<ListGroupsResponse>;
}
export declare function queryGroups(httpClient: HttpClient): QueryGroupsSignature;
interface QueryGroupsSignature {
    /**
     * Retrieves up to 100 groups, given the provided paging, filtering, and sorting.
     *
     * Supported fields for filtering:
     * - `title`
     *
     * Supported fields for sorting:
     * - `title`
     * - `createdDate`
     * - `membersCount`
     * - `recentActivityDate`
     *
     * For groups with `group.privacyStatus` set to `SECRET`, only group admins and group members can see the group and its content.
     */
    (options?: QueryGroupsOptions | undefined): GroupsQueryBuilder;
}
export declare const onGroupCreated: EventDefinition<GroupCreatedEnvelope, "wix.social_groups.v2.group_created">;
export declare const onGroupDeleted: EventDefinition<GroupDeletedEnvelope, "wix.social_groups.v2.group_deleted">;
export declare const onGroupCoverChanged: EventDefinition<GroupCoverChangedEnvelope, "wix.social_groups.v2.group_group_cover_changed">;
export declare const onGroupDescriptionChanged: EventDefinition<GroupDescriptionChangedEnvelope, "wix.social_groups.v2.group_group_description_changed">;
export declare const onGroupUpdated: EventDefinition<GroupUpdatedEnvelope, "wix.social_groups.v2.group_updated">;
export { AccessRestriction, AccessRestrictionDataOneOf, ActionEvent, AllowPolicy, BMFeatures, BMFeaturesBMFeatures, BaseEventMetadata, ContentType, CoverImage, CreateGroupOptions, CreateGroupRequest, CreateGroupResponse, DeleteGroupRequest, DeleteGroupResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, Events, FeedItemPermissions, FeedPermissions, GetGroupBMFeaturesRequest, GetGroupBMFeaturesResponse, GetGroupBySlugOptions, GetGroupBySlugRequest, GetGroupBySlugResponse, GetGroupIdBySlugRequest, GetGroupIdBySlugResponse, GetGroupMembersGroupIdsRequest, GetGroupMembersGroupIdsResponse, GetGroupOptions, GetGroupRequest, GetGroupResponse, GetPrivacyRequest, GetPrivacyResponse, GlobalFeedPermissions, Group, GroupCoverChanged, GroupCoverChangedEnvelope, GroupCreatedEnvelope, GroupDeletedEnvelope, GroupDescriptionChanged, GroupDescriptionChangedEnvelope, GroupDetails, GroupDetailsPosition, GroupIntegrationsData, GroupPermissions, GroupSettings, GroupUpdatedEnvelope, GroupWithMsId, GroupsQueryBuilder, GroupsQueryResult, IdentificationData, IdentificationDataIdOneOf, Identity, IdentityType, Image, ListGroupIntegrationsDataRequest, ListGroupIntegrationsDataResponse, ListGroupsByUserIdRequest, ListGroupsByUserIdResponse, ListGroupsOptions, ListGroupsRequest, ListGroupsResponse, Logo, MembershipStatus, MessageEnvelope, OnboardingStepSettings, Paging, PagingMetadata, Position, PrivacyStatus, Query, QueryGroupsByMembershipRequest, QueryGroupsByMembershipResponse, QueryGroupsOptions, QueryGroupsRequest, QueryGroupsResponse, QueryJoinedGroupsRequest, QueryJoinedGroupsResponse, QueryJoinedGroupsWithMemberRequest, QueryJoinedGroupsWithMemberResponse, RestoreInfo, SortOrder, Sorting, StepKey, Type, UpdateGroup, UpdateGroupOptions, UpdateGroupRequest, UpdateGroupResponse, WebhookIdentityType, } from './social-groups-v2-group-groups.universal.js';
